Documentation
¶
Index ¶
- Variables
- func CacheExpires(r *http.Response) time.Time
- func Version()
- type APIClient
- type APIKey
- type APIResponse
- type AccessTokenResponse
- type AmfSaveOption
- type BasicAuth
- type Box
- type ColladaSaveOption
- type ColladaTransformStyle
- type Configuration
- type CopyFileOpts
- type CopyFolderOpts
- type CreateFolderOpts
- type Cylinder
- type DeleteFileOpts
- type DeleteFolderOpts
- type DeleteNodesOpts
- type DiscUsage
- type Discreet3DsSaveOption
- type DownloadFileOpts
- type DracoCompressionLevel
- type DracoSaveOption
- type Entity
- type Error
- type ErrorDetails
- type FbxSaveOption
- type FileContentType
- type FileVersion
- type FileVersions
- type FilesList
- type FilesUploadResult
- type GenericSwaggerError
- type GetDiscUsageOpts
- type GetFileVersionsOpts
- type GetFilesListOpts
- type GltfSaveOption
- type HtmlSaveOption
- type ModelData
- type ModelError
- type MoveFileOpts
- type MoveFolderOpts
- type ObjSaveOption
- type ObjectExist
- type ObjectExistsOpts
- type PdfLightingScheme
- type PdfRenderMode
- type PdfSaveOption
- type Plane
- type PlySaveOption
- type PostConvertByFormatOpts
- type PostConvertByOptOpts
- type PostModelOpts
- type PostPdfRawDataOpts
- type PostSaveAsPartOpts
- type PostSceneToFileOpts
- type PostTriangulateNewOpts
- type PostTriangulateOriginalOpts
- type PostTriangulatePartOpts
- type RvmSaveOption
- type SaveFormat
- type SaveOptions
- type Sphere
- type StlSaveOption
- type StorageExist
- type StorageFile
- type ThreeDCloudApiService
- func (a *ThreeDCloudApiService) CopyFile(ctx context.Context, srcPath string, destPath string, ...) (*http.Response, error)
- func (a *ThreeDCloudApiService) CopyFolder(ctx context.Context, srcPath string, destPath string, ...) (*http.Response, error)
- func (a *ThreeDCloudApiService) CreateFolder(ctx context.Context, path string, localVarOptionals *CreateFolderOpts) (*http.Response, error)
- func (a *ThreeDCloudApiService) DeleteFile(ctx context.Context, path string, localVarOptionals *DeleteFileOpts) (*http.Response, error)
- func (a *ThreeDCloudApiService) DeleteFolder(ctx context.Context, path string, localVarOptionals *DeleteFolderOpts) (*http.Response, error)
- func (a *ThreeDCloudApiService) DeleteNodes(ctx context.Context, name string, objectaddressingpath string, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) DownloadFile(ctx context.Context, path string, localVarOptionals *DownloadFileOpts) ([]byte, *os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) GetDiscUsage(ctx context.Context, localVarOptionals *GetDiscUsageOpts) (DiscUsage, *http.Response, error)
- func (a *ThreeDCloudApiService) GetFileVersions(ctx context.Context, path string, localVarOptionals *GetFileVersionsOpts) (FileVersions, *http.Response, error)
- func (a *ThreeDCloudApiService) GetFilesList(ctx context.Context, path string, localVarOptionals *GetFilesListOpts) (FilesList, *http.Response, error)
- func (a *ThreeDCloudApiService) MoveFile(ctx context.Context, srcPath string, destPath string, ...) (*http.Response, error)
- func (a *ThreeDCloudApiService) MoveFolder(ctx context.Context, srcPath string, destPath string, ...) (*http.Response, error)
- func (a *ThreeDCloudApiService) OAuthPost(ctx context.Context, grantType string, clientId string, clientSecret string) (AccessTokenResponse, *http.Response, error)
- func (a *ThreeDCloudApiService) ObjectExists(ctx context.Context, path string, localVarOptionals *ObjectExistsOpts) (ObjectExist, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByAmfSaveOption(ctx context.Context, name string, saveOptions *AmfSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByColladaSaveOption(ctx context.Context, name string, saveOptions *ColladaSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByDiscreet3DsSaveOption(ctx context.Context, name string, saveOptions *Discreet3DsSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByDracoSaveOption(ctx context.Context, name string, saveOptions *DracoSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByFbxSaveOption(ctx context.Context, name string, saveOptions *FbxSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByFormat(ctx context.Context, name string, newformat string, newfilename string, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByGltfSaveOption(ctx context.Context, name string, saveOptions *GltfSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByObjSaveOption(ctx context.Context, name string, saveOptions *ObjSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByPdfSaveOption(ctx context.Context, name string, saveOptions *PdfSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByPlySaveOption(ctx context.Context, name string, saveOptions *PlySaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByRvmSaveOption(ctx context.Context, name string, saveOptions *RvmSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByStlSaveOption(ctx context.Context, name string, saveOptions *StlSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostConvertByU3DSaveOption(ctx context.Context, name string, saveOptions *U3DSaveOption, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostCreate(ctx context.Context, format string) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostModel(ctx context.Context, name string, modeldata ModelData, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostPdfRawData(ctx context.Context, name string, multifileprefix string, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostSaveAsPart(ctx context.Context, name string, objectaddressingpath string, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostSceneToFile(ctx context.Context, name string, multifileprefix string, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostTriangulateNew(ctx context.Context, name string, newfilename string, newformat string, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostTriangulateOriginal(ctx context.Context, name string, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) PostTriangulatePart(ctx context.Context, name string, objectaddressingpath string, ...) (*os.File, *http.Response, error)
- func (a *ThreeDCloudApiService) StorageExists(ctx context.Context, storageName string) (StorageExist, *http.Response, error)
- func (a *ThreeDCloudApiService) UploadFile(ctx context.Context, path string, file *os.File, ...) (FilesUploadResult, *http.Response, error)
- type TokenResp
- type Torus
- type Transform
- type U3DSaveOption
- type UploadFileOpts
- type Vector3
Constants ¶
This section is empty.
Variables ¶
var ( // ContextOAuth2 takes a oauth2.TokenSource as authentication for the request. ContextOAuth2 = contextKey("token") // ContextBasicAuth takes BasicAuth as authentication for the request. ContextBasicAuth = contextKey("basic") // ContextAccessToken takes a string oauth2 access token as authentication for the request. ContextAccessToken = contextKey("accesstoken") // ContextAPIKey takes an APIKey as authentication for the request ContextAPIKey = contextKey("apikey") )
Functions ¶
func CacheExpires ¶
CacheExpires helper function to determine remaining time before repeating a request.
Types ¶
type APIClient ¶
type APIClient struct {
ThreeDCloudApi *ThreeDCloudApiService
// contains filtered or unexported fields
}
APIClient manages communication with the Aspose.3D Cloud API Reference API v3.0 In most cases there should be only one, shared, APIClient.
func NewAPIClient ¶
func NewAPIClient(cfg *Configuration) *APIClient
NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.
func (*APIClient) ChangeBasePath ¶
Change base path to allow switching to mocks
func (*APIClient) RequestOauthToken ¶
RequestOauthToken function for requests OAuth token
type APIKey ¶
APIKey provides API key based authentication to a request passed via context using ContextAPIKey
type APIResponse ¶
type APIResponse struct {
*http.Response `json:"-"`
Message string `json:"message,omitempty"`
// Operation is the name of the swagger operation.
Operation string `json:"operation,omitempty"`
// RequestURL is the request URL. This value is always available, even if the
// embedded *http.Response is nil.
RequestURL string `json:"url,omitempty"`
// Method is the HTTP method used for the request. This value is always
// available, even if the embedded *http.Response is nil.
Method string `json:"method,omitempty"`
// Payload holds the contents of the response body (which may be nil or empty).
// This is provided here as the raw response.Body() reader will have already
// been drained.
Payload []byte `json:"-"`
}
func NewAPIResponse ¶
func NewAPIResponse(r *http.Response) *APIResponse
func NewAPIResponseWithError ¶
func NewAPIResponseWithError(errorMessage string) *APIResponse
type AccessTokenResponse ¶
type AccessTokenResponse struct {
Expires string `json:".expires,omitempty"`
AccessToken string `json:"access_token,omitempty"`
Issued string `json:".issued,omitempty"`
ClientRefreshTokenLifeTimeInMinutes string `json:"clientRefreshTokenLifeTimeInMinutes,omitempty"`
ExpiresIn int64 `json:"expires_in,omitempty"`
TokenType string `json:"token_type,omitempty"`
ClientId string `json:"client_id,omitempty"`
RefreshToken string `json:"refresh_token,omitempty"`
}
type AmfSaveOption ¶
type AmfSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Whether to use compression to reduce the final file size, default value is true.
EnableCompression bool `json:"EnableCompression,omitempty"`
}
type BasicAuth ¶
type BasicAuth struct {
UserName string `json:"userName,omitempty"`
Password string `json:"password,omitempty"`
}
BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth
type Box ¶
type Box struct {
// Gets or sets the length of the box
Length float64 `json:"Length"`
// Gets or sets the width of the box
Width float64 `json:"Width"`
// Gets or sets the height of the box
Height float64 `json:"Height"`
// Gets or sets the name of the box
Name string `json:"Name,omitempty"`
// Gets or sets the lengthSegments of the box
LengthSegments int32 `json:"LengthSegments"`
// Gets or sets the widthSegments of the box
WidthSegments int32 `json:"WidthSegments"`
// Gets or sets the heightSegments of the box
HeightSegments int32 `json:"HeightSegments"`
}
The Box Entity
type ColladaSaveOption ¶
type ColladaSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Gets or sets whether the exported XML document is indented.
Indented bool `json:"Indented,omitempty"`
// Gets or sets of the Transform Style.
TransformStyle *ColladaTransformStyle `json:"TransformStyle,omitempty"`
}
type ColladaTransformStyle ¶
type ColladaTransformStyle int32
ColladaTransformStyle : The node's transform style of node.
const ( ColladaTransformStyle_Components ColladaTransformStyle = 0 ColladaTransformStyle_Matrix ColladaTransformStyle = 1 )
List of ColladaTransformStyle
type Configuration ¶
type Configuration struct {
BasePath string `json:"basePath,omitempty"`
Host string `json:"host,omitempty"`
Scheme string `json:"scheme,omitempty"`
DefaultHeader map[string]string `json:"defaultHeader,omitempty"`
UserAgent string `json:"userAgent,omitempty"`
HTTPClient *http.Client
AppKey string
AppSid string
AccessToken string
}
func NewConfiguration ¶
func NewConfiguration(appSid string, appKey string, basePath string) *Configuration
func (*Configuration) AddDefaultHeader ¶
func (c *Configuration) AddDefaultHeader(key string, value string)
type CopyFileOpts ¶
type CopyFolderOpts ¶
type CreateFolderOpts ¶
type Cylinder ¶
type Cylinder struct {
// Gets or sets the name of the cylinder
Name string `json:"Name,omitempty"`
// Gets or sets the radius of cylinder's top cap.
RadiusTop float64 `json:"RadiusTop"`
// Gets or sets the radius bottoof cylinder's bottom cap.
RadiusBottom float64 `json:"RadiusBottom"`
// Gets or sets the height of the cylinder.
Height float64 `json:"Height"`
// Gets or sets the radial segments.
RadialSegments int32 `json:"RadialSegments"`
// Gets or sets the height segments.
HeightSegments int32 `json:"HeightSegments"`
// Gets or sets a value indicating whether this Aspose.ThreeD.Entities.Cylinder open ended. The default value is false.
OpenEnded bool `json:"OpenEnded"`
// Gets or sets the theta start. The default value is 0.
ThetaStart float64 `json:"ThetaStart"`
// Gets or sets the length of the theta. The default value is 2p
ThetaLength float64 `json:"ThetaLength"`
}
type DeleteFileOpts ¶
type DeleteFolderOpts ¶
type DeleteNodesOpts ¶
type DiscUsage ¶
type DiscUsage struct {
// Application used disc space.
UsedSize int64 `json:"UsedSize"`
// Total disc space.
TotalSize int64 `json:"TotalSize"`
}
Class for disc space information.
type Discreet3DsSaveOption ¶
type Discreet3DsSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Gets or sets whether export all lights in the scene.
ExportLight bool `json:"ExportLight,omitempty"`
// Gets or sets whether export all cameras in the scene
ExportCamera bool `json:"ExportCamera,omitempty"`
// The separator between object's name and the duplicated counter, default value is \"_\". When scene contains objects that use the same name, Aspose.3D 3DS exporter will generate a different name for the object. For example there's two nodes named \"Box\", the first node will have a name \"Box\", and the second node will get a new name \"Box_2\" using the default configuration
DuplicatedNameSeparator string `json:"DuplicatedNameSeparator,omitempty"`
// The counter used by generating new name for duplicated names
DuplicatedNameCounterBase int32 `json:"DuplicatedNameCounterBase,omitempty"`
// The format of the duplicated counter, default value is empty string.
DuplicatedNameCounterFormat string `json:"DuplicatedNameCounterFormat,omitempty"`
// Gets or sets the master scale used in exporting.
MasterScale float64 `json:"MasterScale,omitempty"`
// Gets or sets the GammaCorrectedColor.
GammaCorrectedColor bool `json:"GammaCorrectedColor,omitempty"`
// Gets or sets flip coordinate system of control points/normal during importing/exporting..
FlipCoordinateSystem bool `json:"FlipCoordinateSystem,omitempty"`
// Gets or sets the HighPreciseColor.
HighPreciseColor bool `json:"HighPreciseColor,omitempty"`
}
type DownloadFileOpts ¶
type DracoCompressionLevel ¶
type DracoCompressionLevel int32
DracoCompressionLevel : Compression level for draco file
const ( DracoCompressionLevel_NoCompression DracoCompressionLevel = 0 DracoCompressionLevel_Fast DracoCompressionLevel = 1 DracoCompressionLevel_Standard DracoCompressionLevel = 2 DracoCompressionLevel_Optimal DracoCompressionLevel = 3 )
List of DracoCompressionLevel
type DracoSaveOption ¶
type DracoSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Quantization bits for position, default value is 14
PositionBits int32 `json:"PositionBits,omitempty"`
// Quantization bits for texture coordinate, default value is 12
TextureCoordinateBits int32 `json:"TextureCoordinateBits,omitempty"`
// Quantization bits for vertex color, default value is 10
ColorBits int32 `json:"ColorBits,omitempty"`
// Quantization bits for normal vectors, default value is 10
NormalBits int32 `json:"NormalBits,omitempty"`
// Compression level, default value is Aspose.ThreeD.Formats.DracoCompressionLevel.Standard.
CompressionLevel *DracoCompressionLevel `json:"CompressionLevel,omitempty"`
}
type Entity ¶
type Entity struct {
// Box/Cylinder/Sphere/Torus/Plane
Type_ string `json:"Type,omitempty"`
// Gets or sets Box entity
Box *Box `json:"Box,omitempty"`
// Gets or sets Cylinder entity
Cylinder *Cylinder `json:"Cylinder,omitempty"`
// Gets or sets Sphere entity
Sphere *Sphere `json:"Sphere,omitempty"`
// Gets or sets Torus entity
Torus *Torus `json:"Torus,omitempty"`
// Gets or sets Plane entity
Plane *Plane `json:"Plane,omitempty"`
}
Entity class
type Error ¶
type Error struct {
// Code
Code string `json:"Code,omitempty"`
// Message
Message string `json:"Message,omitempty"`
// Description
Description string `json:"Description,omitempty"`
// Inner Error
InnerError *ErrorDetails `json:"InnerError,omitempty"`
}
Error
type ErrorDetails ¶
type ErrorDetails struct {
// The request id
RequestId string `json:"RequestId,omitempty"`
// Date
Date time.Time `json:"Date"`
}
The error details
type FbxSaveOption ¶
type FbxSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Compression large binary data in the FBX file, default value is true
EnableCompression bool `json:"EnableCompression,omitempty"`
// Gets or sets whether reuse repeated curve data by increasing last data's ref count
FoldRepeatedCurveData bool `json:"FoldRepeatedCurveData,omitempty"`
// Gets or sets whether export legacy material properties, used for back compatibility. This option is turned on by default
ExportLegacyMaterialProperties bool `json:"ExportLegacyMaterialProperties,omitempty"`
// Gets or sets whether generate a Video instance for Aspose.ThreeD.Shading.Texture when exporting as FBX.
VideoForTexture bool `json:"VideoForTexture,omitempty"`
// Gets or sets whether always generate a Aspose.ThreeD.Entities.VertexElementMaterial for geometries if the attached node contains materials. This is turned off by default.
GenerateVertexElementMaterial bool `json:"GenerateVertexElementMaterial,omitempty"`
}
type FileContentType ¶
type FileContentType int32
FileContentType : File content type
const ( FileContentType_Binary FileContentType = 0 FileContentType_ASCII FileContentType = 1 )
List of FileContentType
type FileVersion ¶
type FileVersion struct {
// File or folder name.
Name string `json:"Name,omitempty"`
// True if it is a folder.
IsFolder bool `json:"IsFolder"`
// File or folder last modified DateTime.
ModifiedDate time.Time `json:"ModifiedDate,omitempty"`
// File or folder size.
Size int64 `json:"Size"`
// File or folder path.
Path string `json:"Path,omitempty"`
// File Version ID.
VersionId string `json:"VersionId,omitempty"`
// Specifies whether the file is (true) or is not (false) the latest version of an file.
IsLatest bool `json:"IsLatest"`
}
File Version
type FileVersions ¶
type FileVersions struct {
// File versions FileVersion.
Value []FileVersion `json:"Value,omitempty"`
}
File versions FileVersion.
type FilesList ¶
type FilesList struct {
// Files and folders contained by folder StorageFile.
Value []StorageFile `json:"Value,omitempty"`
}
Files list
type FilesUploadResult ¶
type FilesUploadResult struct {
// List of uploaded file names
Uploaded []string `json:"Uploaded,omitempty"`
// List of errors.
Errors []ModelError `json:"Errors,omitempty"`
}
File upload result
type GenericSwaggerError ¶
type GenericSwaggerError struct {
// contains filtered or unexported fields
}
GenericSwaggerError Provides access to the body, error and model on returned errors.
func (GenericSwaggerError) Body ¶
func (e GenericSwaggerError) Body() []byte
Body returns the raw bytes of the response
func (GenericSwaggerError) Error ¶
func (e GenericSwaggerError) Error() string
Error returns non-empty string if there was an error.
func (GenericSwaggerError) Model ¶
func (e GenericSwaggerError) Model() interface{}
Model returns the unpacked model of the error
type GetDiscUsageOpts ¶
type GetFileVersionsOpts ¶
type GetFilesListOpts ¶
type GltfSaveOption ¶
type GltfSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// The JSON content of GLTF file is indented for human reading, default value is false.
PrettyPrint bool `json:"PrettyPrint,omitempty"`
// Embed all external assets as base64 into single file in ASCII mode, default value is false.
EmbedAssets bool `json:"EmbedAssets,omitempty"`
// Serialize materials using KHR common material extensions, default value is false. Set this to false will cause Aspose.3D export a set of vertex/fragment shader if Aspose.ThreeD.Formats.GLTFSaveOptions.ExportShaders
UseCommonMaterials bool `json:"UseCommonMaterials,omitempty"`
// Flip texture coordinate v(t) component, default value is true.
FlipTexCoordV bool `json:"FlipTexCoordV,omitempty"`
// The file name of the external buffer file used to store binary data. If this file is not specified, Aspose.3D will generate a name for you. This is ignored when export glTF in binary mode.
BufferFile bool `json:"BufferFile,omitempty"`
// Save scene object's dynamic properties into 'extra' fields in the generated glTF file. This is useful to provide application-specific data. Default value is false..
SaveExtras bool `json:"SaveExtras,omitempty"`
// Gets or sets whether to enable draco compression.
DracoCompression bool `json:"DracoCompression,omitempty"`
// Gets or sets of the FileContent type.
FileContentType *FileContentType `json:"FileContentType,omitempty"`
}
type HtmlSaveOption ¶
type HtmlSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Display a grid in the scene. Default value is true.
ShowGrid bool `json:"ShowGrid,omitempty"`
// Display rulers of x/y/z axises in the scene to measure the model. Default value is false
ShowRulers bool `json:"ShowRulers,omitempty"`
// Display a simple UI in the scene. Default value is true
ShowUI bool `json:"ShowUI,omitempty"`
// Display a orientation box. Default value is true.
OrientationBox bool `json:"OrientationBox,omitempty"`
// Gets or sets the up vector, value can be \"x\"/\"y\"/\"z\", default value is \"y\".
UpVector string `json:"UpVector,omitempty"`
// Gets or sets the far plane of the camera, default value is 1000
FarPlane float64 `json:"FarPlane,omitempty"`
// Gets or sets the near plane of the camera, default value is 1
NearPlane float64 `json:"NearPlane,omitempty"`
// Gets or sets the default look at position, default value is (0, 0, 0)
LookAt *Vector3 `json:"LookAt,omitempty"`
// Gets or sets the initial position of the camera, default value is (10, 10, 10)
CameraPosition *Vector3 `json:"CameraPosition,omitempty"`
// Gets or sets the field of the view, default value is 45, measured in degree
FieldOfView float64 `json:"FieldOfView,omitempty"`
}
type ModelData ¶
type ModelData struct {
// e.g Node
Type_ string `json:"Type,omitempty"`
Transform *Transform `json:"Transform,omitempty"`
Entity *Entity `json:"Entity,omitempty"`
}
Parametric Modeling
type ModelError ¶
type ModelError struct {
// Code
Code string `json:"Code,omitempty"`
// Message
Message string `json:"Message,omitempty"`
// Description
Description string `json:"Description,omitempty"`
// Inner Error
InnerError *ErrorDetails `json:"InnerError,omitempty"`
}
Error
type MoveFileOpts ¶
type MoveFolderOpts ¶
type ObjSaveOption ¶
type ObjSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Gets or sets whether generate comments for each section.
Verbose bool `json:"Verbose,omitempty"`
// Gets or sets whether serialize W component in model's vertex position.
SerializeW bool `json:"SerializeW,omitempty"`
// Gets or sets whether import/export materials for each object.
EnableMaterials bool `json:"EnableMaterials,omitempty"`
// Gets or sets whether flip coordinate system of control points/normal during importing/exporting.
FlipCoordinateSystem bool `json:"FlipCoordinateSystem,omitempty"`
}
type ObjectExist ¶
type ObjectExist struct {
// Indicates that the file or folder exists.
Exists bool `json:"Exists"`
// True if it is a folder, false if it is a file.
IsFolder bool `json:"IsFolder"`
}
Object exists
type ObjectExistsOpts ¶
type PdfLightingScheme ¶
type PdfLightingScheme int32
PdfLightingScheme : Render mode specifies the style in which the 3D artwork is rendered.
const ( PdfLightingScheme_Artwork PdfLightingScheme = 0 PdfLightingScheme_None PdfLightingScheme = 1 PdfLightingScheme_White PdfLightingScheme = 2 PdfLightingScheme_Day PdfLightingScheme = 3 PdfLightingScheme_Night PdfLightingScheme = 4 PdfLightingScheme_Hard PdfLightingScheme = 5 PdfLightingScheme_Primary PdfLightingScheme = 6 PdfLightingScheme_Blue PdfLightingScheme = 7 PdfLightingScheme_Red PdfLightingScheme = 8 PdfLightingScheme_Cube PdfLightingScheme = 8 PdfLightingScheme_CAD PdfLightingScheme = 10 PdfLightingScheme_Headlamp PdfLightingScheme = 11 )
List of PdfLightingScheme
type PdfRenderMode ¶
type PdfRenderMode int32
PdfRenderMode : Render mode specifies the style in which the 3D artwork is rendered.
const ( PdfRenderMode_Solid PdfRenderMode = 0 PdfRenderMode_SolidWireframe PdfRenderMode = 1 PdfRenderMode_Transparent PdfRenderMode = 2 PdfRenderMode_TransparentWireframe PdfRenderMode = 3 PdfRenderMode_BoundingBox PdfRenderMode = 4 PdfRenderMode_TransparentBoundingBox PdfRenderMode = 5 PdfRenderMode_TransparentBoundingBoxOutline PdfRenderMode = 6 PdfRenderMode_Wireframe PdfRenderMode = 7 PdfRenderMode_ShadedWireframe PdfRenderMode = 8 PdfRenderMode_HiddenWireframe PdfRenderMode = 9 PdfRenderMode_Vertices PdfRenderMode = 10 PdfRenderMode_ShadedVertices PdfRenderMode = 11 PdfRenderMode_Illustration PdfRenderMode = 12 PdfRenderMode_SolidOutline PdfRenderMode = 13 PdfRenderMode_ShadedIllustration PdfRenderMode = 14 )
List of PdfRenderMode
type PdfSaveOption ¶
type PdfSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Gets or sets to flip the coordinate system of the scene during exporting.
FlipCoordinateSystem bool `json:"FlipCoordinateSystem,omitempty"`
// Render mode specifies the style in which the 3D artwork is rendered.
RenderMode *PdfRenderMode `json:"RenderMode,omitempty"`
// LightingScheme specifies the lighting to apply to 3D artwork.
LightingScheme *PdfLightingScheme `json:"LightingScheme,omitempty"`
}
type Plane ¶
type Plane struct {
// The name of Plane
Name string `json:"Name,omitempty"`
// Gets or sets the length of the plane.
Length float64 `json:"Length"`
// Gets or sets the width of the plane
Width float64 `json:"Width"`
// Gets or sets the length segments.
LengthSegments int32 `json:"LengthSegments"`
// Gets or sets the width segments.
WidthSegments int32 `json:"WidthSegments"`
}
Plane Entity
type PlySaveOption ¶
type PlySaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Flip the coordinate while saving the scene, default value is true.
FlipCoordinate bool `json:"FlipCoordinate,omitempty"`
// The element name for the vertex data, default value is \"vertex\".
VertexElement string `json:"VertexElement,omitempty"`
// The component names for position data, default value is (\"x\", \"y\", \"z\")
PositionComponents []string `json:"PositionComponents,omitempty"`
// The element name for the face data, default value is face.
FaceElement string `json:"FaceElement,omitempty"`
// The property name for the face data, default value is vertex_index.
FaceProperty string `json:"FaceProperty,omitempty"`
// Gets or sets of the FileContent Style.
FileContentType *FileContentType `json:"FileContentType,omitempty"`
}
type PostConvertByFormatOpts ¶
type PostConvertByOptOpts ¶
type PostConvertByOptOpts struct {
Folder optional.String
IsOverwrite optional.Bool
Storage optional.String
}
**************NOTE**************** Since I do not know how to realize.so please change each class for different saveoptions AmfSaveOption ColladaSaveOption Discreet3DsSaveOption DracoSaveOption FbxSaveOption GltfSaveOption HTMLaveOption ObjSaveOption PdfSaveOption PlySaveOption RvmSaveOption StlSaveOption U3DSaveOption ***********************************
type PostModelOpts ¶
type PostPdfRawDataOpts ¶
type PostSaveAsPartOpts ¶
type PostSceneToFileOpts ¶
type PostTriangulateNewOpts ¶
type PostTriangulatePartOpts ¶
type RvmSaveOption ¶
type RvmSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// File note in the file header.
FileNote string `json:"FileNote,omitempty"`
// Author information, default value is '3d@aspose'.
Author string `json:"Author,omitempty"`
// The timestamp that exported this file, default value is current time.
CreationTime string `json:"CreationTime,omitempty"`
// Gets or sets of the FileContent Style.
FileContentType *FileContentType `json:"FileContentType,omitempty"`
}
type SaveFormat ¶
type SaveFormat int32
SaveFormat : SaveFormat type
const ( SaveFormat_AMF SaveFormat = 0 SaveFormat_ASE SaveFormat = 1 SaveFormat_Aspose3DWeb SaveFormat = 2 SaveFormat_Collada SaveFormat = 3 SaveFormat_Discreet3DS SaveFormat = 4 SaveFormat_Draco SaveFormat = 5 SaveFormat_DXF SaveFormat = 6 SaveFormat_FBX SaveFormat = 7 SaveFormat_GLTF SaveFormat = 8 SaveFormat_HTML SaveFormat = 9 SaveFormat_Microsoft3MF SaveFormat = 10 SaveFormat_JT SaveFormat = 11 SaveFormat_Obj SaveFormat = 12 SaveFormat_PDF SaveFormat = 13 SaveFormat_PLY SaveFormat = 14 SaveFormat_Rvm SaveFormat = 15 SaveFormat_STL SaveFormat = 16 SaveFormat_U3D SaveFormat = 17 SaveFormat_VRML SaveFormat = 18 SaveFormat_X SaveFormat = 19 )
List of SaveFormat
type SaveOptions ¶
type SaveOptions struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
}
type Sphere ¶
type Sphere struct {
// Gets or sets the Name of Sphere.
Name string `json:"Name,omitempty"`
// Gets or sets the width segments.
WidthSegments int32 `json:"WidthSegments"`
// Gets or sets the height segments.
HeightSegments int32 `json:"HeightSegments"`
// Gets or sets the phi start.
PhiStart float64 `json:"PhiStart"`
// Gets or sets the length of the phi.
PhiLength float64 `json:"PhiLength"`
// Gets or sets the theta start.
ThetaStart float64 `json:"ThetaStart"`
// Gets or sets the length of the theta.
ThetaLength float64 `json:"ThetaLength"`
// Gets or sets the radius
Radius float64 `json:"Radius"`
}
The Sphere Entity
type StlSaveOption ¶
type StlSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Gets or sets whether flip coordinate system of control points/normal during exporting.
FlipCoordinateSystem bool `json:"FlipCoordinateSystem,omitempty"`
// Gets or sets of the FileContent Style.
FileContentType *FileContentType `json:"FileContentType,omitempty"`
}
type StorageExist ¶
type StorageExist struct {
// Shows that the storage exists.
Exists bool `json:"Exists"`
}
Storage exists
type StorageFile ¶
type StorageFile struct {
// File or folder name.
Name string `json:"Name,omitempty"`
// True if it is a folder.
IsFolder bool `json:"IsFolder"`
// File or folder last modified DateTime.
ModifiedDate time.Time `json:"ModifiedDate,omitempty"`
// File or folder size.
Size int64 `json:"Size"`
// File or folder path.
Path string `json:"Path,omitempty"`
}
File or folder information
type ThreeDCloudApiService ¶
type ThreeDCloudApiService service
func NewThreeDCloudApiService ¶
func NewThreeDCloudApiService(appSid string, appKey string, basePath string) *ThreeDCloudApiService
func (*ThreeDCloudApiService) CopyFile ¶
func (a *ThreeDCloudApiService) CopyFile(ctx context.Context, srcPath string, destPath string, localVarOptionals *CopyFileOpts) (*http.Response, error)
func (*ThreeDCloudApiService) CopyFolder ¶
func (a *ThreeDCloudApiService) CopyFolder(ctx context.Context, srcPath string, destPath string, localVarOptionals *CopyFolderOpts) (*http.Response, error)
func (*ThreeDCloudApiService) CreateFolder ¶
func (a *ThreeDCloudApiService) CreateFolder(ctx context.Context, path string, localVarOptionals *CreateFolderOpts) (*http.Response, error)
func (*ThreeDCloudApiService) DeleteFile ¶
func (a *ThreeDCloudApiService) DeleteFile(ctx context.Context, path string, localVarOptionals *DeleteFileOpts) (*http.Response, error)
func (*ThreeDCloudApiService) DeleteFolder ¶
func (a *ThreeDCloudApiService) DeleteFolder(ctx context.Context, path string, localVarOptionals *DeleteFolderOpts) (*http.Response, error)
func (*ThreeDCloudApiService) DeleteNodes ¶
func (*ThreeDCloudApiService) DownloadFile ¶
func (*ThreeDCloudApiService) GetDiscUsage ¶
func (a *ThreeDCloudApiService) GetDiscUsage(ctx context.Context, localVarOptionals *GetDiscUsageOpts) (DiscUsage, *http.Response, error)
func (*ThreeDCloudApiService) GetFileVersions ¶
func (a *ThreeDCloudApiService) GetFileVersions(ctx context.Context, path string, localVarOptionals *GetFileVersionsOpts) (FileVersions, *http.Response, error)
func (*ThreeDCloudApiService) GetFilesList ¶
func (a *ThreeDCloudApiService) GetFilesList(ctx context.Context, path string, localVarOptionals *GetFilesListOpts) (FilesList, *http.Response, error)
func (*ThreeDCloudApiService) MoveFile ¶
func (a *ThreeDCloudApiService) MoveFile(ctx context.Context, srcPath string, destPath string, localVarOptionals *MoveFileOpts) (*http.Response, error)
func (*ThreeDCloudApiService) MoveFolder ¶
func (a *ThreeDCloudApiService) MoveFolder(ctx context.Context, srcPath string, destPath string, localVarOptionals *MoveFolderOpts) (*http.Response, error)
func (*ThreeDCloudApiService) OAuthPost ¶
func (a *ThreeDCloudApiService) OAuthPost(ctx context.Context, grantType string, clientId string, clientSecret string) (AccessTokenResponse, *http.Response, error)
ThreeDCloudApiService Get Access token
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param grantType Grant Type
- @param clientId App SID
- @param clientSecret App Key
@return AccessTokenResponse
func (*ThreeDCloudApiService) ObjectExists ¶
func (a *ThreeDCloudApiService) ObjectExists(ctx context.Context, path string, localVarOptionals *ObjectExistsOpts) (ObjectExist, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByAmfSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByAmfSaveOption(ctx context.Context, name string, saveOptions *AmfSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByColladaSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByColladaSaveOption(ctx context.Context, name string, saveOptions *ColladaSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByDiscreet3DsSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByDiscreet3DsSaveOption(ctx context.Context, name string, saveOptions *Discreet3DsSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByDracoSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByDracoSaveOption(ctx context.Context, name string, saveOptions *DracoSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByFbxSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByFbxSaveOption(ctx context.Context, name string, saveOptions *FbxSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByFormat ¶
func (*ThreeDCloudApiService) PostConvertByGltfSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByGltfSaveOption(ctx context.Context, name string, saveOptions *GltfSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByObjSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByObjSaveOption(ctx context.Context, name string, saveOptions *ObjSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (a *ThreeDCloudApiService) PostConvertByHTMLaveOption(ctx context.Context, name string, saveOptions* HTMLaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error) {
var (
localVarHttpMethod = strings.ToUpper("Post")
localVarPostBody interface{}
localVarFileName string
localVarFileBytes []byte
localVarReturnValue *os.File
)
// create path and map variables
localVarPath := a.client.cfg.BasePath + "/3d/saveas/saveoption"
localVarHeaderParams := make(map[string]string)
localVarQueryParams := url.Values{}
localVarFormParams := url.Values{}
localVarQueryParams.Add("name", parameterToString(name, ""))
localVarQueryParams.Add("newfilename", parameterToString(newfilename, ""))
if localVarOptionals != nil && localVarOptionals.Folder.IsSet() {
localVarQueryParams.Add("folder", parameterToString(localVarOptionals.Folder.Value(), ""))
}
if localVarOptionals != nil && localVarOptionals.IsOverwrite.IsSet() {
localVarQueryParams.Add("IsOverwrite", parameterToString(localVarOptionals.IsOverwrite.Value(), ""))
}
if localVarOptionals != nil && localVarOptionals.Storage.IsSet() {
localVarQueryParams.Add("storage", parameterToString(localVarOptionals.Storage.Value(), ""))
}
// to determine the Content-Type header
localVarHttpContentTypes := []string{"application/json"}
// set Content-Type header
localVarHttpContentType := selectHeaderContentType(localVarHttpContentTypes)
if localVarHttpContentType != "" {
localVarHeaderParams["Content-Type"] = localVarHttpContentType
}
// to determine the Accept header
localVarHttpHeaderAccepts := []string{"application/json"}
// set Accept header
localVarHttpHeaderAccept := selectHeaderAccept(localVarHttpHeaderAccepts)
if localVarHttpHeaderAccept != "" {
localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
}
// body params
localVarPostBody = saveOptions
fmt.Printf("\nlocalVarPostBody %s \n\n",localVarPostBody)//debug
r, err := a.client.prepareRequest(ctx, localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)
if err != nil {
return localVarReturnValue, nil, err
}
localVarHttpResponse, err := a.client.callAPI(r)
if err != nil || localVarHttpResponse == nil {
return localVarReturnValue, localVarHttpResponse, err
}
localVarBody, err := ioutil.ReadAll(localVarHttpResponse.Body)
//fmt.Printf("localVarBody %v \n",localVarBody)//debug
localVarHttpResponse.Body.Close()
if err != nil {
return localVarReturnValue, localVarHttpResponse, err
}
if localVarHttpResponse.StatusCode < 300 {
// If we succeed, return the data, otherwise pass on to decode error.
err = a.client.decode(&localVarReturnValue, localVarBody, localVarHttpResponse.Header.Get("Content-Type"));
if err == nil {
return localVarReturnValue, localVarHttpResponse, err
}
}
if localVarHttpResponse.StatusCode >= 300 {
newErr := GenericSwaggerError{
body: localVarBody,
error: localVarHttpResponse.Status,
}
if localVarHttpResponse.StatusCode == 200 {
var v *os.File
err = a.client.decode(&v, localVarBody, localVarHttpResponse.Header.Get("Content-Type"));
if err != nil {
newErr.error = err.Error()
return localVarReturnValue, localVarHttpResponse, newErr
}
newErr.model = v
return localVarReturnValue, localVarHttpResponse, newErr
}
return localVarReturnValue, localVarHttpResponse, newErr
}
return localVarReturnValue, localVarHttpResponse, nil
}
func (*ThreeDCloudApiService) PostConvertByPdfSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByPdfSaveOption(ctx context.Context, name string, saveOptions *PdfSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByPlySaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByPlySaveOption(ctx context.Context, name string, saveOptions *PlySaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByRvmSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByRvmSaveOption(ctx context.Context, name string, saveOptions *RvmSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByStlSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByStlSaveOption(ctx context.Context, name string, saveOptions *StlSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostConvertByU3DSaveOption ¶
func (a *ThreeDCloudApiService) PostConvertByU3DSaveOption(ctx context.Context, name string, saveOptions *U3DSaveOption, newfilename string, localVarOptionals *PostConvertByOptOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostCreate ¶
func (a *ThreeDCloudApiService) PostCreate(ctx context.Context, format string) (*os.File, *http.Response, error)
ThreeDCloudApiService Create new file with specified format.
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param format The format of the new file.
@return *os.File
func (*ThreeDCloudApiService) PostPdfRawData ¶
func (*ThreeDCloudApiService) PostSaveAsPart ¶
func (*ThreeDCloudApiService) PostSceneToFile ¶
func (*ThreeDCloudApiService) PostTriangulateNew ¶
func (*ThreeDCloudApiService) PostTriangulateOriginal ¶
func (a *ThreeDCloudApiService) PostTriangulateOriginal(ctx context.Context, name string, localVarOptionals *PostTriangulateOriginalOpts) (*os.File, *http.Response, error)
func (*ThreeDCloudApiService) PostTriangulatePart ¶
func (*ThreeDCloudApiService) StorageExists ¶
func (a *ThreeDCloudApiService) StorageExists(ctx context.Context, storageName string) (StorageExist, *http.Response, error)
ThreeDCloudApiService Check if storage exists
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param storageName Storage name
@return StorageExist
func (*ThreeDCloudApiService) UploadFile ¶
func (a *ThreeDCloudApiService) UploadFile(ctx context.Context, path string, file *os.File, localVarOptionals *UploadFileOpts) (FilesUploadResult, *http.Response, error)
type TokenResp ¶
type TokenResp struct {
AccessToken string `json:"access_token"`
TokenType string `json:"token_type"`
ExpiresIn int64 `json:"expires_in"`
}
TokenResp represents data returned by GetAccessToken and RefreshToken as HTTP response body.
type Torus ¶
type Torus struct {
// Gets or sets the Name of the torus.
Name string `json:"Name,omitempty"`
// Gets or sets the radius of the torus.
Radius float64 `json:"Radius"`
// Gets or sets the radius of the tube.
Tube float64 `json:"Tube"`
// Gets or sets the radial segments.
RadialSegments int32 `json:"RadialSegments"`
// Gets or sets the tubular segments.
TubularSegments int32 `json:"TubularSegments"`
// Gets or sets the arc.
Arc float64 `json:"Arc"`
}
The Torus Entity class
type Transform ¶
type Transform struct {
// Gets or sets the translation
Translation *Vector3 `json:"Translation,omitempty"`
// Gets or sets the scale
Scale *Vector3 `json:"Scale,omitempty"`
// Gets or sets the pre-rotation represented in degree
PreRotation *Vector3 `json:"PreRotation,omitempty"`
// Gets or sets the post-rotation represented in degree
PostRotation *Vector3 `json:"PostRotation,omitempty"`
// Gets or sets the rotation represented in euler angles, measured in degree
EulerAngles *Vector3 `json:"EulerAngles,omitempty"`
}
A transform contains information that allow access to object's translate/scale/rotation or transform matrix at minimum cost This is used by local transform.
type U3DSaveOption ¶
type U3DSaveOption struct {
// Gets or sets of the SaveFormat.
SaveFormat SaveFormat `json:"SaveFormat,omitempty"`
// Some files like OBJ depends on external file, the lookup paths will allows Aspose.3D to look for external file to load
LookupPaths []string `json:"LookupPaths,omitempty"`
// The file name of the exporting/importing scene. This is optional, but useful when serialize external assets like OBJ's material.
FileName string `json:"FileName,omitempty"`
// The file format like FBX,U3D,PDF ....
FileFormat string `json:"FileFormat,omitempty"`
// Gets or sets whether flip coordinate system of control points/normal during importing/exporting.
FlipCoordinateSystem bool `json:"FlipCoordinateSystem,omitempty"`
// Gets or sets whether to enable mesh data compression.
MeshCompression bool `json:"MeshCompression,omitempty"`
// Gets or sets whether to export normal data.
ExportNormals bool `json:"ExportNormals,omitempty"`
// Gets or sets whether to export texture coordinates.
ExportTextureCoordinates bool `json:"ExportTextureCoordinates,omitempty"`
// Gets or sets whether to export vertex's diffuse color.
ExportVertexDiffuse bool `json:"ExportVertexDiffuse,omitempty"`
// Gets or sets whether to export vertex' specular color.
ExportVertexSpecular bool `json:"ExportVertexSpecular,omitempty"`
}
type UploadFileOpts ¶
type Vector3 ¶
type Vector3 struct {
// The x component.
X float64 `json:"x"`
// The y component.
Y float64 `json:"y"`
// The z component.
Z float64 `json:"z"`
// Gets the square of the length.
Length2 float64 `json:"Length2"`
// Gets the length of this vector.
Length float64 `json:"Length"`
}
A vector with three components.
Source Files
¶
- access_token_response.go
- amf_save_option.go
- box.go
- client.go
- collada_save_option.go
- collada_transform_style.go
- configuration.go
- cylinder.go
- disc_usage.go
- discreet3_ds_save_option.go
- draco_compression_level.go
- draco_save_option.go
- entity.go
- error.go
- error_details.go
- fbx_save_option.go
- file_content_type.go
- file_version.go
- file_versions.go
- files_list.go
- files_upload_result.go
- gltf_save_option.go
- html_save_option.go
- model_data.go
- model_error.go
- obj_save_option.go
- object_exist.go
- pdf_lighting_scheme.go
- pdf_render_mode.go
- pdf_save_option.go
- plane.go
- ply_save_option.go
- response.go
- rvm_save_option.go
- save_format.go
- save_options.go
- sphere.go
- stl_save_option.go
- storage_exist.go
- storage_file.go
- three_d_cloud.go
- torus.go
- transform.go
- u3_d_save_option.go
- vector3.go